import { useContext, useState } from "react";
import CatalogueContext from "../contexts/CatalogueContext";
import { Model } from "@gooddata/react-components";

const useYearFilter = (initialSelectedYear = new Date().getFullYear()) => {
    const [selectedYear, setSelectedYear] = useState(initialSelectedYear);
    const catalogue = useContext(CatalogueContext);

    if (catalogue.isLoading || catalogue.error || !catalogue.data) {
        return [{ ...catalogue, data: null }, undefined, setSelectedYear];
    }

    const dateDateSetIdentifier = catalogue.data.defaultDateDataSet;

    return [
        { data: selectedYear, isLoading: false, error: null }, // resource state representing the selected year, it is loading if the catalogue is still loading
        Model.absoluteDateFilter(dateDateSetIdentifier, `${selectedYear}-01-01`, `${selectedYear}-12-31`), // filter ready to be used in visualizations
        setSelectedYear, // function for setting the selected year value
    ];
};

export default useYearFilter;
